photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlersend.h
branchRCL_3
changeset 25 191387a8b767
parent 13 71da52165949
--- a/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlersend.h	Wed Apr 14 15:57:24 2010 +0300
+++ b/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlersend.h	Tue Apr 27 16:37:53 2010 +0300
@@ -51,13 +51,15 @@
 	{
 public:  // Constructors and destructor
 	/**
-	* Two-phased constructor.
-    * @param aMediaListProvider pointer to media list owner
-    * @param aHasToolbarItem Whether Command Should be toolbar item (ETrue - if toolbar item)
-    * @return pointer to CGlxCommandHandlerSend object
-    */
-	IMPORT_C static CGlxCommandHandlerSend* NewL( 
-				MGlxMediaListProvider* aMediaListProvider, TBool aHasToolbarItem );
+	 * Two-phased constructor.
+	 * @param aMediaListProvider pointer to media list owner
+	 * @param aHasToolbarItem Whether Command Should be toolbar item (ETrue - if toolbar item)
+	 * @param aFileName resource file
+	 * @return pointer to CGlxCommandHandlerSend object
+	 */
+	IMPORT_C static CGlxCommandHandlerSend* NewL(
+			MGlxMediaListProvider* aMediaListProvider, TBool aHasToolbarItem,
+			const TDesC& aFileName);
     
     /**
     * Destructor.
@@ -73,9 +75,9 @@
 
 private:
 	/**
-    * Symbian 2nd phase constructor
-	*/
-    void ConstructL();
+	 * Symbian 2nd phase constructor
+	 */
+	void ConstructL(const TDesC& aFileName);
 
     /**
     * C++ default constructor.
@@ -157,11 +159,10 @@
     				TInt aOldIndex, MGlxMediaList* aList);
 
     /**
-    * not implemented
 	* @ref MGlxMediaListObserver::HandleItemSelectedL
 	*/
-    void HandleItemSelectedL(TInt /*aIndex*/, TBool /*aSelected*/, 
-    							MGlxMediaList* /*aList*/){};
+    void HandleItemSelectedL(TInt aIndex, TBool aSelected, 
+    							MGlxMediaList* aList);
 
     /**
     * not implemented
@@ -190,9 +191,10 @@
 	void SendSelectedItemsL();
 	
 	/**
-	* Load the resource file
-	*/
-	void LoadRscFileL();	
+	 * Load the resource file
+	 * @param aFileName resource file
+	 */
+	void LoadRscFileL(const TDesC& aFileName);	
 
 	/**
 	* Return the static capabilities for sending a media item